@@ -327,19 +327,21 @@ InitGlobals();
 warn "Saving ...\n";
 $canvas = IUP::Canvas::FileVector->new( format=>"SVG", filename=>"tmp-testoutput.svg", width=>270.933, height=>198.543, dpi=>120 );
 SimpleDraw($canvas);
-#$canvas->cdKillCanvas(); 
-#$canvas->DESTROY(); 
+$canvas->cdKillCanvas(); 
 undef $canvas; #XXX-FIXME why we need 'undef $canvas' and '$canvas->cdKillCanvas()' is not enough?
 
 warn "Saving ...\n";
 $canvas = IUP::Canvas::FileVector->new( format=>"EMF", filename=>"tmp-testoutput.emf", width=>1280, height=>938 );
 SimpleDraw($canvas);
+$canvas->cdKillCanvas;
 undef $canvas;
 
 warn "Saving ...\n";
 $canvas = IUP::Canvas::FileBitmap->new( width=>1280, height=>938, dpi=>120 );
 SimpleDraw($canvas);
+$canvas->cdDumpBitmap("tmp-testoutput.jpg", "JPEG");
 $canvas->cdDumpBitmap("tmp-testoutput.png", "PNG");
+$canvas->cdKillCanvas;
 undef $canvas;
 
 warn "Done!\n";
\ No newline at end of file
