@@ -6,9 +6,7 @@ use IUP::Internal::LibraryIup;
 
 sub _create_element {
   my ($self, $args, $firstonly) = @_;
-  my $ih = IUP::Internal::LibraryIup::_IupDial($args->{TYPE});
-  delete $args->{TYPE};
-  return $ih;
+  return IUP::Internal::LibraryIup::_IupDial(delete $args->{TYPE});
 }
 
 1;
