@@ -1,4 +1,6 @@
 package IUP::Sbox;
+use strict;
+use warnings;
 use base 'IUP::Internal::Element';
 use IUP::Internal::LibraryIup;
 
